@@ -41,6 +41,8 @@
 #include <avahi-glib/glib-malloc.h>
 #endif 
 
+#include <dbus/dbus-glib-bindings.h>
+
 #include "seahorse-gpgmex.h"
 #include "seahorse-util.h"
 #include "seahorse-gconf.h"
@@ -60,7 +62,7 @@ seahorse_util_show_error (GtkWindow *parent, const gchar *heading, const gchar *
         t = g_strdup (message);
 	
 	error = gtk_message_dialog_new_with_markup (parent, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
-		GTK_BUTTONS_CLOSE, t);
+		GTK_BUTTONS_CLOSE, t, NULL);
     g_free (t);
 	
 	gtk_dialog_run (GTK_DIALOG (error));
@@ -114,7 +116,12 @@ seahorse_util_handle_error (GError* err, const char* desc, ...)
     if (desc)
         t = g_strdup_vprintf (desc, ap);
     
-    va_end(ap);        
+    va_end(ap);    
+    
+    /* Never show an error for 'cancelled' */
+    if (err->code == DBUS_GERROR_REMOTE_EXCEPTION && err->domain == DBUS_GERROR && 
+        strstr (dbus_g_error_get_name (err), "Cancelled"))
+	    return;
     
     seahorse_util_show_error (NULL, t, err->message ? err->message : "");
     g_free(t);
@@ -629,7 +636,7 @@ seahorse_util_uris_package (const gchar* package, const char** uris)
     g_free (cmd); 
     
     if (out) {
-        g_print (out);
+        g_print (out, NULL);
         g_free (out);
     }
     
